@@ -25,6 +25,7 @@
 
 #include <KLocalizedString>
 #include <Kdelibs4ConfigMigrator>
+#include <KCrash>
 
 #include <QApplication>
 #include <QFontDatabase>
@@ -130,6 +131,8 @@ int main(int argc, char **argv)
 
     KAboutData::setApplicationData(aboutData);
 
+    KCrash::initialize();
+
     QFont f(QStringLiteral("Domestic Manners"), 12, QFont::Normal, true);
     if (!QFontInfo(f).exactMatch())
     {
